@@ -70,9 +70,7 @@ QVariant OutputModel::data(const QModelIndex &index, int role) const
     case NormalizedPositionRole:
         return output->geometry().topLeft();
     case AutoRotateRole:
-        return m_config->autoRotate(output);
-    case AutoRotateOnlyInTabletModeRole:
-        return m_config->autoRotateOnlyInTabletMode(output);
+        return static_cast<uint32_t>(output->autoRotatePolicy());
     case RotationRole:
         return output->rotation();
     case ScaleRole:
@@ -109,6 +107,8 @@ QVariant OutputModel::data(const QModelIndex &index, int role) const
         return static_cast<uint32_t>(output->rgbRange());
     case InteractiveMoveRole:
         return m_outputs[index.row()].moving;
+    case IccProfileRole:
+        return output->iccProfilePath();
     }
     return QVariant();
 }
@@ -165,13 +165,14 @@ bool OutputModel::setData(const QModelIndex &index, const QVariant &value, int r
         return false;
         break;
     case AutoRotateRole:
-        if (value.canConvert<bool>()) {
-            return setAutoRotate(index.row(), value.value<bool>());
-        }
-        break;
-    case AutoRotateOnlyInTabletModeRole:
-        if (value.canConvert<bool>()) {
-            return setAutoRotateOnlyInTabletMode(index.row(), value.value<bool>());
+        if (value.canConvert<uint32_t>()) {
+            Output &output = m_outputs[index.row()];
+            const auto policy = static_cast<KScreen::Output::AutoRotatePolicy>(value.toUInt());
+            if (output.ptr->autoRotatePolicy() == policy) {
+                return false;
+            }
+            output.ptr->setAutoRotatePolicy(policy);
+            Q_EMIT dataChanged(index, index, {AutoRotateRole});
         }
         break;
     case RotationRole:
@@ -249,6 +250,10 @@ bool OutputModel::setData(const QModelIndex &index, const QVariant &value, int r
             return true;
         }
         break;
+    case IccProfileRole:
+        m_outputs[index.row()].ptr->setIccProfilePath(value.toString());
+        Q_EMIT dataChanged(index, index, {role});
+        return true;
     }
     return false;
 }
@@ -263,7 +268,6 @@ QHash<int, QByteArray> OutputModel::roleNames() const
     roles[PositionRole] = "position";
     roles[NormalizedPositionRole] = "normalizedPosition";
     roles[AutoRotateRole] = "autoRotate";
-    roles[AutoRotateOnlyInTabletModeRole] = "autoRotateOnlyInTabletMode";
     roles[RotationRole] = "rotation";
     roles[ScaleRole] = "scale";
     roles[ResolutionIndexRole] = "resolutionIndex";
@@ -279,6 +283,7 @@ QHash<int, QByteArray> OutputModel::roleNames() const
     roles[VrrPolicyRole] = "vrrPolicy";
     roles[RgbRangeRole] = "rgbRange";
     roles[InteractiveMoveRole] = "interactiveMove";
+    roles[IccProfileRole] = "iccProfilePath";
     return roles;
 }
 
@@ -343,7 +348,7 @@ void OutputModel::resetPosition(Output &output)
 {
     if (!output.posReset.has_value()) {
         // KCM was closed in between.
-        for (const Output &out : qAsConst(m_outputs)) {
+        for (const Output &out : std::as_const(m_outputs)) {
             if (out.ptr->id() == output.ptr->id()) {
                 continue;
             }
@@ -384,7 +389,7 @@ void OutputModel::resetPosition(Output &output)
 
 QPoint OutputModel::mostTopLeftLocationOfPositionableOutputOptionallyIgnoringOneOfThem(std::optional<KScreen::OutputPtr> ignored) const
 {
-    auto foldTopLeft = [=](std::optional<QPoint> a, const Output &out) {
+    auto foldTopLeft = [this, ignored](std::optional<QPoint> a, const Output &out) {
         if (!positionable(out) || (ignored.has_value() && out.ptr->id() == ignored.value()->id())) {
             return a;
         }
@@ -521,34 +526,6 @@ bool OutputModel::setRefreshRate(int outputIndex, int refIndex)
     return true;
 }
 
-bool OutputModel::setAutoRotate(int outputIndex, bool value)
-{
-    Output &output = m_outputs[outputIndex];
-
-    if (m_config->autoRotate(output.ptr) == value) {
-        return false;
-    }
-    m_config->setAutoRotate(output.ptr, value);
-
-    QModelIndex index = createIndex(outputIndex, 0);
-    Q_EMIT dataChanged(index, index, {AutoRotateRole});
-    return true;
-}
-
-bool OutputModel::setAutoRotateOnlyInTabletMode(int outputIndex, bool value)
-{
-    Output &output = m_outputs[outputIndex];
-
-    if (m_config->autoRotateOnlyInTabletMode(output.ptr) == value) {
-        return false;
-    }
-    m_config->setAutoRotateOnlyInTabletMode(output.ptr, value);
-
-    QModelIndex index = createIndex(outputIndex, 0);
-    Q_EMIT dataChanged(index, index, {AutoRotateOnlyInTabletModeRole});
-    return true;
-}
-
 bool OutputModel::setRotation(int outputIndex, KScreen::Output::Rotation rotation)
 {
     const Output &output = m_outputs[outputIndex];
@@ -667,9 +644,9 @@ QVariantList OutputModel::resolutionsStrings(const KScreen::OutputPtr &output) c
     return ret;
 }
 
-QVector<QSize> OutputModel::resolutions(const KScreen::OutputPtr &output) const
+QList<QSize> OutputModel::resolutions(const KScreen::OutputPtr &output) const
 {
-    QVector<QSize> hits;
+    QList<QSize> hits;
 
     const auto modes = output->modes();
     for (const auto &mode : modes) {
@@ -690,9 +667,9 @@ QVector<QSize> OutputModel::resolutions(const KScreen::OutputPtr &output) const
     return hits;
 }
 
-QVector<float> OutputModel::refreshRates(const KScreen::OutputPtr &output) const
+QList<float> OutputModel::refreshRates(const KScreen::OutputPtr &output) const
 {
-    QVector<float> hits;
+    QList<float> hits;
 
     QSize baseSize;
     if (output->currentMode()) {
@@ -836,7 +813,7 @@ QVariantList OutputModel::replicasModel(const KScreen::OutputPtr &output) const
     return ret;
 }
 
-void OutputModel::rolesChanged(int outputId, const QVector<int> &roles)
+void OutputModel::rolesChanged(int outputId, const QList<int> &roles)
 {
     const auto index = indexForOutputId(outputId);
     if (index.isValid()) {
@@ -871,7 +848,7 @@ void OutputModel::reposition()
     int y = 0;
 
     // Find first valid output.
-    for (const auto &out : qAsConst(m_outputs)) {
+    for (const auto &out : std::as_const(m_outputs)) {
         if (positionable(out)) {
             x = out.ptr->pos().x();
             y = out.ptr->pos().y();
@@ -1063,7 +1040,7 @@ void OutputModel::snap(const Output &output, QPoint &dest)
     const QSize size = output.ptr->geometry().size();
     const QRect outputRect(dest, size);
 
-    QVector<std::reference_wrapper<const Output>> positionableOutputs;
+    QList<std::reference_wrapper<const Output>> positionableOutputs;
     positionableOutputs.reserve(m_outputs.size());
     std::copy_if(m_outputs.cbegin(), m_outputs.cend(), std::back_inserter(positionableOutputs), [](const Output &output) {
         return output.ptr->isPositionable();
@@ -1109,7 +1086,7 @@ void OutputModel::snap(const Output &output, QPoint &dest)
         return;
     }
 
-    for (const Output &out : qAsConst(positionableOutputs)) {
+    for (const Output &out : std::as_const(positionableOutputs)) {
         if (out.ptr->id() == output.ptr->id()) {
             // Can not snap to itself.
             continue;
@@ -1165,3 +1142,5 @@ void OutputModel::maintainSnapping(const OutputModel::Output &changedOutput, con
         updatePositions();
     }
 }
+
+#include "moc_output_model.cpp"
