@@ -28,7 +28,6 @@ public:
         /** Position for backend relative to most northwest display corner. */
         NormalizedPositionRole,
         AutoRotateRole,
-        AutoRotateOnlyInTabletModeRole,
         RotationRole,
         ScaleRole,
         ResolutionIndexRole,
@@ -43,6 +42,7 @@ public:
         OverscanRole,
         VrrPolicyRole,
         RgbRangeRole,
+        IccProfileRole,
         InteractiveMoveRole, // This output is currently repositioned interactively
     };
 
@@ -108,7 +108,7 @@ private:
         bool moving = false;
     };
 
-    void rolesChanged(int outputId, const QVector<int> &roles);
+    void rolesChanged(int outputId, const QList<int> &roles);
     QModelIndex indexForOutputId(int outputId) const;
 
     void resetPosition(Output &output);
@@ -129,15 +129,13 @@ private:
     bool setResolution(int outputIndex, int resIndex);
     bool setRefreshRate(int outputIndex, int refIndex);
     bool setRotation(int outputIndex, KScreen::Output::Rotation rotation);
-    bool setAutoRotate(int outputIndex, bool value);
-    bool setAutoRotateOnlyInTabletMode(int outputIndex, bool value);
 
     int resolutionIndex(const KScreen::OutputPtr &output) const;
     int refreshRateIndex(const KScreen::OutputPtr &output) const;
     QSize resolution(const KScreen::OutputPtr &output) const;
     QVariantList resolutionsStrings(const KScreen::OutputPtr &output) const;
-    QVector<QSize> resolutions(const KScreen::OutputPtr &output) const;
-    QVector<float> refreshRates(const KScreen::OutputPtr &output) const;
+    QList<QSize> resolutions(const KScreen::OutputPtr &output) const;
+    QList<float> refreshRates(const KScreen::OutputPtr &output) const;
 
     bool positionable(const Output &output) const;
 
@@ -148,7 +146,7 @@ private:
 
     QVariantList replicasModel(const KScreen::OutputPtr &output) const;
 
-    QVector<Output> m_outputs;
+    QList<Output> m_outputs;
 
     ConfigHandler *m_config;
 };
