@@ -9,12 +9,10 @@
 */
 #include "daemon.h"
 
-#include "../common/orientation_sensor.h"
 #include "config.h"
 #include "device.h"
 #include "generator.h"
 #include "kscreen_daemon_debug.h"
-#include "kscreenadaptor.h"
 #include "osdservice_interface.h"
 
 #include <kscreen/configmonitor.h>
@@ -33,17 +31,12 @@
 
 #include <QAction>
 #include <QGuiApplication>
-#include <QOrientationReading>
 #include <QScreen>
 #include <QShortcut>
 #include <QTimer>
 
 #if HAVE_X11
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <QX11Info>
-#else
-#include <private/qtx11extras_p.h>
-#endif
+#include <QtGui/private/qtx11extras_p.h>
 #include <X11/Xatom.h>
 #include <X11/Xlib-xcb.h>
 #include <X11/extensions/XInput.h>
@@ -78,25 +71,10 @@ KScreenDaemon::KScreenDaemon(QObject *parent, const QList<QVariant> &)
     , m_changeCompressor(new QTimer(this))
     , m_saveTimer(nullptr)
     , m_lidClosedTimer(new QTimer(this))
-    , m_orientationSensor(new OrientationSensor(this))
 {
-    connect(m_orientationSensor, &OrientationSensor::availableChanged, this, &KScreenDaemon::updateOrientation);
-    connect(m_orientationSensor, &OrientationSensor::valueChanged, this, &KScreenDaemon::updateOrientation);
-
     KScreen::Log::instance();
     qMetaTypeId<KScreen::OsdAction>();
     QMetaObject::invokeMethod(this, "getInitialConfig", Qt::QueuedConnection);
-
-    auto dpms = new KScreen::Dpms(this);
-    connect(dpms, &KScreen::Dpms::modeChanged, this, [this](KScreen::Dpms::Mode mode, QScreen *screen) {
-        if (m_monitoredConfig && m_monitoredConfig->data() && screen->geometry() == m_monitoredConfig->data()->primaryOutput()->geometry()) {
-            if (mode == KScreen::Dpms::On) {
-                m_orientationSensor->setEnabled(m_monitoredConfig->autoRotationRequested());
-            } else {
-                m_orientationSensor->setEnabled(false);
-            }
-        }
-    });
 }
 
 void KScreenDaemon::getInitialConfig()
@@ -127,12 +105,10 @@ void KScreenDaemon::init()
     KActionCollection *coll = new KActionCollection(this);
     QAction *action = coll->addAction(QStringLiteral("display"));
     action->setText(i18n("Switch Display"));
-    QList<QKeySequence> switchDisplayShortcuts({Qt::Key_Display, Qt::MetaModifier + Qt::Key_P});
+    QList<QKeySequence> switchDisplayShortcuts({Qt::Key_Display, Qt::MetaModifier | Qt::Key_P});
     KGlobalAccel::self()->setGlobalShortcut(action, switchDisplayShortcuts);
     connect(action, &QAction::triggered, this, &KScreenDaemon::displayButton);
 
-    new KScreenAdaptor(this);
-
     const QString osdService = QStringLiteral("org.kde.kscreen.osdService");
     const QString osdPath = QStringLiteral("/org/kde/kscreen/osdService");
     m_osdServiceInterface = new OrgKdeKscreenOsdServiceInterface(osdService, osdPath, QDBusConnection::sessionBus(), this);
@@ -150,7 +126,6 @@ void KScreenDaemon::init()
     connect(Device::self(), &Device::lidClosedChanged, this, &KScreenDaemon::lidClosedChanged);
     connect(Device::self(), &Device::resumingFromSuspend, this, [this]() {
         KScreen::Log::instance()->setContext(QStringLiteral("resuming"));
-        m_orientationSensor->setEnabled(m_monitoredConfig->autoRotationRequested());
         qCDebug(KSCREEN_KDED) << "Resumed from suspend, checking for screen changes";
         // We don't care about the result, we just want to force the backend
         // to query XRandR so that it will detect possible changes that happened
@@ -161,7 +136,6 @@ void KScreenDaemon::init()
         qCDebug(KSCREEN_KDED) << "System is going to suspend, won't be changing config (waited for "
                               << (m_lidClosedTimer->interval() - m_lidClosedTimer->remainingTime()) << "ms)";
         m_lidClosedTimer->stop();
-        m_orientationSensor->setEnabled(false);
     });
 
     connect(Generator::self(), &Generator::ready, this, [this] {
@@ -178,39 +152,6 @@ void KScreenDaemon::init()
     monitorConnectedChange();
 }
 
-void KScreenDaemon::updateOrientation()
-{
-    if (!m_monitoredConfig) {
-        return;
-    }
-    const auto features = m_monitoredConfig->data()->supportedFeatures();
-    if (!features.testFlag(KScreen::Config::Feature::AutoRotation) || !features.testFlag(KScreen::Config::Feature::TabletMode)) {
-        return;
-    }
-
-    if (!m_orientationSensor->available() || !m_orientationSensor->enabled()) {
-        return;
-    }
-
-    const auto orientation = m_orientationSensor->value();
-    if (orientation == QOrientationReading::Undefined) {
-        // Orientation sensor went off. Do not change current orientation.
-        return;
-    }
-    if (orientation == QOrientationReading::FaceUp || orientation == QOrientationReading::FaceDown) {
-        // We currently don't do anything with FaceUp/FaceDown, but in the future we could use them
-        // to shut off and switch on again a display when display is facing downwards/upwards.
-        return;
-    }
-
-    m_monitoredConfig->setDeviceOrientation(orientation);
-    if (m_monitoring) {
-        doApplyConfig(m_monitoredConfig->data());
-    } else {
-        m_configDirty = true;
-    }
-}
-
 void KScreenDaemon::doApplyConfig(const KScreen::ConfigPtr &config)
 {
     qCDebug(KSCREEN_KDED) << "Do set and apply specific config";
@@ -225,12 +166,6 @@ void KScreenDaemon::doApplyConfig(std::unique_ptr<Config> config)
     m_monitoredConfig = std::move(config);
 
     m_monitoredConfig->activateControlWatching();
-    m_orientationSensor->setEnabled(m_monitoredConfig->autoRotationRequested());
-
-    connect(m_monitoredConfig.get(), &Config::controlChanged, this, [this]() {
-        m_orientationSensor->setEnabled(m_monitoredConfig->autoRotationRequested());
-        updateOrientation();
-    });
 
     refreshConfig();
 }
@@ -275,81 +210,13 @@ void KScreenDaemon::applyKnownConfig()
     }
 }
 
-void KScreenDaemon::applyLayoutPreset(const QString &presetName)
-{
-    const QMetaEnum actionEnum = QMetaEnum::fromType<KScreen::OsdAction::Action>();
-    Q_ASSERT(actionEnum.isValid());
-
-    bool ok;
-    auto action = static_cast<KScreen::OsdAction::Action>(actionEnum.keyToValue(qPrintable(presetName), &ok));
-    if (!ok) {
-        qCWarning(KSCREEN_KDED) << "Cannot apply unknown screen layout preset named" << presetName;
-        return;
-    }
-    applyOsdAction(action);
-}
-
-bool KScreenDaemon::getAutoRotate()
-{
-    return m_monitoredConfig->getAutoRotate();
-}
-
-void KScreenDaemon::setAutoRotate(bool value)
-{
-    if (!m_monitoredConfig) {
-        return;
-    }
-    m_monitoredConfig->setAutoRotate(value);
-    m_orientationSensor->setEnabled(value);
-}
-
-bool KScreenDaemon::isAutoRotateAvailable()
-{
-    return m_orientationSensor->available();
-}
-
 void KScreenDaemon::showOSD()
 {
-    auto call = m_osdServiceInterface->showActionSelector();
-    auto watcher = new QDBusPendingCallWatcher(call);
-    connect(watcher, &QDBusPendingCallWatcher::finished, this, [this, watcher] {
-        watcher->deleteLater();
-        QDBusReply<int> reply = *watcher;
-        if (!reply.isValid()) {
-            return;
-        }
-        applyOsdAction(static_cast<KScreen::OsdAction::Action>(reply.value()));
-    });
-}
-
-void KScreenDaemon::applyOsdAction(KScreen::OsdAction::Action action)
-{
-    switch (action) {
-    case KScreen::OsdAction::NoAction:
-        qCDebug(KSCREEN_KDED) << "OSD: no action";
-        return;
-    case KScreen::OsdAction::SwitchToInternal:
-        qCDebug(KSCREEN_KDED) << "OSD: switch to internal";
-        doApplyConfig(Generator::self()->displaySwitch(Generator::TurnOffExternal));
-        return;
-    case KScreen::OsdAction::SwitchToExternal:
-        qCDebug(KSCREEN_KDED) << "OSD: switch to external";
-        doApplyConfig(Generator::self()->displaySwitch(Generator::TurnOffEmbedded));
-        return;
-    case KScreen::OsdAction::ExtendLeft:
-        qCDebug(KSCREEN_KDED) << "OSD: extend left";
-        doApplyConfig(Generator::self()->displaySwitch(Generator::ExtendToLeft));
-        return;
-    case KScreen::OsdAction::ExtendRight:
-        qCDebug(KSCREEN_KDED) << "OSD: extend right";
-        doApplyConfig(Generator::self()->displaySwitch(Generator::ExtendToRight));
-        return;
-    case KScreen::OsdAction::Clone:
-        qCDebug(KSCREEN_KDED) << "OSD: clone";
-        doApplyConfig(Generator::self()->displaySwitch(Generator::Clone));
-        return;
-    }
-    Q_UNREACHABLE();
+    QDBusMessage message = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kscreen.osdService"),
+                                                          QStringLiteral("/org/kde/kscreen/osdService"),
+                                                          QStringLiteral("org.kde.kscreen.osdService"),
+                                                          QStringLiteral("showActionSelector"));
+    QDBusConnection::sessionBus().asyncCall(message);
 }
 
 void KScreenDaemon::applyIdealConfig()
@@ -636,14 +503,6 @@ void KScreenDaemon::outputConnectedChanged()
 
     KScreen::Output *output = qobject_cast<KScreen::Output *>(sender());
     qCDebug(KSCREEN_KDED) << "outputConnectedChanged():" << output->name();
-
-    if (output->isConnected()) {
-        Q_EMIT outputConnected(output->name());
-
-        if (!m_monitoredConfig->fileExists()) {
-            Q_EMIT unknownOutputConnected(output->name());
-        }
-    }
 }
 
 void KScreenDaemon::monitorConnectedChange()
