@@ -4,8 +4,7 @@
 
     SPDX-License-Identifier: GPL-2.0-or-later
 */
-#ifndef KSCREEN_DAEMON_H
-#define KSCREEN_DAEMON_H
+#pragma once
 
 #include "../common/globals.h"
 #include "../common/osdaction.h"
@@ -20,7 +19,6 @@
 #include <memory>
 
 class Config;
-class OrientationSensor;
 class OrgKdeKscreenOsdServiceInterface;
 
 namespace KScreen
@@ -39,18 +37,6 @@ public:
     KScreenDaemon(QObject *parent, const QList<QVariant> &);
     ~KScreenDaemon() override;
 
-public Q_SLOTS:
-    // DBus
-    void applyLayoutPreset(const QString &presetName);
-    bool getAutoRotate();
-    void setAutoRotate(bool value);
-    bool isAutoRotateAvailable();
-
-Q_SIGNALS:
-    // DBus
-    void outputConnected(const QString &outputName);
-    void unknownOutputConnected(const QString &outputName);
-
 private:
     Q_INVOKABLE void getInitialConfig();
     void init();
@@ -70,7 +56,6 @@ private:
 
     void outputConnectedChanged();
     void showOSD();
-    void applyOsdAction(KScreen::OsdAction::Action action);
 
     void doApplyConfig(const KScreen::ConfigPtr &config);
     void doApplyConfig(std::unique_ptr<Config> config);
@@ -79,8 +64,6 @@ private:
     void monitorConnectedChange();
     void disableOutput(const KScreen::OutputPtr &output);
 
-    void updateOrientation();
-
     std::unique_ptr<Config> m_monitoredConfig;
     bool m_monitoring;
     bool m_configDirty = true;
@@ -88,9 +71,6 @@ private:
     QTimer *m_saveTimer;
     QTimer *m_lidClosedTimer;
     OrgKdeKscreenOsdServiceInterface *m_osdServiceInterface;
-    OrientationSensor *m_orientationSensor;
 
     bool m_startingUp = true;
 };
-
-#endif /*KSCREEN_DAEMON_H*/
