@@ -16,20 +16,22 @@
 #include <KScreen/Config>
 #include <KScreen/ConfigMonitor>
 #include <KScreen/GetConfigOperation>
+#include <KScreen/Mode>
 #include <KScreen/Output>
+#include <KScreen/SetConfigOperation>
 
 #include <algorithm>
 
 KScreenApplet::KScreenApplet(QObject *parent, const KPluginMetaData &data, const QVariantList &args)
     : Plasma::Applet(parent, data, args)
 {
+    qmlRegisterUncreatableType<KScreen::OsdAction>("org.kde.private.kscreen", 1, 0, "OsdAction", QStringLiteral("Can't create OsdAction"));
 }
 
 KScreenApplet::~KScreenApplet() = default;
 
 void KScreenApplet::init()
 {
-    qmlRegisterUncreatableType<KScreen::OsdAction>("org.kde.private.kscreen", 1, 0, "OsdAction", QStringLiteral("Can't create OsdAction"));
     connect(new KScreen::GetConfigOperation(KScreen::GetConfigOperation::NoEDID),
             &KScreen::ConfigOperation::finished,
             this,
@@ -48,24 +50,9 @@ int KScreenApplet::connectedOutputCount() const
     return m_connectedOutputCount;
 }
 
-void KScreenApplet::applyLayoutPreset(Action action)
+void KScreenApplet::applyLayoutPreset(KScreen::OsdAction::Action action)
 {
-    const QMetaEnum actionEnum = QMetaEnum::fromType<KScreen::OsdAction::Action>();
-    Q_ASSERT(actionEnum.isValid());
-
-    const QString presetName = QString::fromLatin1(actionEnum.valueToKey(action));
-    if (presetName.isEmpty()) {
-        return;
-    }
-
-    QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kded5"),
-                                                      QStringLiteral("/modules/kscreen"),
-                                                      QStringLiteral("org.kde.KScreen"),
-                                                      QStringLiteral("applyLayoutPreset"));
-
-    msg.setArguments({presetName});
-
-    QDBusConnection::sessionBus().call(msg, QDBus::NoBlock);
+    KScreen::OsdAction::applyAction(m_screenConfiguration, action);
 }
 
 void KScreenApplet::checkOutputs()
@@ -92,6 +79,8 @@ QVariant KScreenApplet::availableActions()
     return QVariant::fromValue(KScreen::OsdAction::availableActions());
 }
 
-K_PLUGIN_CLASS_WITH_JSON(KScreenApplet, "metadata.json")
+K_PLUGIN_CLASS(KScreenApplet)
 
 #include "kscreenapplet.moc"
+
+#include "moc_kscreenapplet.cpp"
